==> haskell-semialign-1.2.0.1-157-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-semialign.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 semialign
version:              1.2.0.1
visibility:           public
id:                   semialign-1.2.0.1-BAKfKqZjRWJ4qgu9C7ztLJ
key:                  semialign-1.2.0.1-BAKfKqZjRWJ4qgu9C7ztLJ
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:
    Align and Zip type-classes from the common Semialign ancestor.

description:
    The major use of @These@ of this is provided by the @align@ member of
    @Semialign@ class, representing a generalized notion of "zipping with padding"
    that combines structures without truncating to the size of the smaller input.

    It turns out that @zip@ operation fits well the @Semialign@ class,
    forming lattice-like structure.

category:             Data, These
abi:                  dbe9cfe40e7183436abceda492e117ee
exposed:              True
exposed-modules:
    Data.Align Data.Crosswalk Data.Semialign Data.Semialign.Indexed
    Data.Zip

hidden-modules:       Data.Semialign.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/semialign-1.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/semialign-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semialign
hs-libraries:         HSsemialign-1.2.0.1-BAKfKqZjRWJ4qgu9C7ztLJ
depends:
    base-4.16.4.0 containers-0.6.5.1
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    indexed-traversable-0.1.3-1Qv6lMYD85cCoJPVws66xH
    indexed-traversable-instances-0.1.1.2-GFPKI9Dgf3mCaH8A902912
    semigroupoids-5.3.7-8VadR23YqgWJtKdu0uOLHe
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    these-1.1.1.1-CyiAda0CLBVAJ3SurHOVRa transformers-0.5.6.2
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-semialign/html/semialign.haddock
haddock-html:         /usr/share/doc/haskell-semialign/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semialign-1.2.0.1-166-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-semialign.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 semialign
version:              1.2.0.1
visibility:           public
id:                   semialign-1.2.0.1-13SzsoAvGga7y3UthWagzb
key:                  semialign-1.2.0.1-13SzsoAvGga7y3UthWagzb
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:
    Align and Zip type-classes from the common Semialign ancestor.

description:
    The major use of @These@ of this is provided by the @align@ member of
    @Semialign@ class, representing a generalized notion of "zipping with padding"
    that combines structures without truncating to the size of the smaller input.

    It turns out that @zip@ operation fits well the @Semialign@ class,
    forming lattice-like structure.

category:             Data, These
abi:                  cd932d06a6ef1e4bc4750a2a3b50f57e
exposed:              True
exposed-modules:
    Data.Align Data.Crosswalk Data.Semialign Data.Semialign.Indexed
    Data.Zip

hidden-modules:       Data.Semialign.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/semialign-1.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/semialign-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semialign
hs-libraries:         HSsemialign-1.2.0.1-13SzsoAvGga7y3UthWagzb
depends:
    base-4.16.4.0 containers-0.6.5.1
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    indexed-traversable-0.1.3-FGAp4VsezN7HyqjQRvrfWc
    indexed-traversable-instances-0.1.1.2-FForVez7QFELsbVgUs4w2Y
    semigroupoids-5.3.7-3HMcZlsRlqoKaeVPumQFHg
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    these-1.1.1.1-FlLT2KU4YN4BBIgA41WfSa transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-semialign/html/semialign.haddock
haddock-html:         /usr/share/doc/haskell-semialign/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
